@@ -6,8 +6,8 @@
 ;; Author: Boris Buliga <boris@d12frosted.io>
 ;; Maintainer: Boris Buliga <boris@d12frosted.io>
 ;; URL: https://github.com/d12frosted/vulpea-ui
-;; Package-Version: 1.1.0
-;; Package-Revision: v1.1.0-0-gfdd6749cb4a2
+;; Package-Version: 20260106.738
+;; Package-Revision: 923975fb209d
 ;; Package-Requires: ((emacs "29.1") (vulpea "2.0.0") (vui "0.1"))
 ;; Keywords: outlines hypermedia
 
@@ -54,7 +54,6 @@
 (require 'org-element)
 (require 'vulpea)
 (require 'vui)
-(require 'vui-components)
 
 
 ;;; Custom variables
@@ -107,6 +106,11 @@ When non-nil, shows a snippet of text around each backlink mention."
   :type 'boolean
   :group 'vulpea-ui)
 
+(defcustom vulpea-ui-backlinks-preview-lines 2
+  "Number of lines to show in backlink previews for prose context."
+  :type 'integer
+  :group 'vulpea-ui)
+
 (defcustom vulpea-ui-backlinks-prose-chars-before 30
   "Number of characters to show before link in prose previews."
   :type 'integer
@@ -309,8 +313,7 @@ Widgets are filtered by predicate and sorted by order."
   "Major mode for the vulpea-ui sidebar buffer.
 \\{vulpea-ui-sidebar-mode-map}"
   :group 'vulpea-ui
-  (setq-local truncate-lines t)
-  (mode-line-invisible-mode 1))
+  (setq-local truncate-lines t))
 
 
 ;;; Sidebar state (frame-local)
@@ -332,7 +335,7 @@ Used to prevent re-entry during render.")
   "Return the sidebar buffer name for FRAME.
 If FRAME is nil, use the selected frame."
   (let ((frame (or frame (selected-frame))))
-    (format "*vulpea-ui-sidebar:%s*" (or (frame-parameter frame 'window-id) ""))))
+    (format "*vulpea-ui-sidebar:%s*" (frame-parameter frame 'name))))
 
 (defun vulpea-ui--get-sidebar-buffer (&optional frame)
   "Get the sidebar buffer for FRAME, or nil if it doesn't exist."
@@ -496,21 +499,14 @@ Called from `window-buffer-change-functions'."
     (vulpea-ui-sidebar-refresh)))
 
 (defun vulpea-ui--on-idle ()
-  "Handle idle timeout - soft refresh preserving memos.
-Only widgets whose deps changed (e.g. `buffer-modified-tick' for
-stats and outline) will recompute."
+  "Handle idle timeout - refresh stats and outline."
   (when (vulpea-ui--sidebar-visible-p)
     (let* ((frame (selected-frame))
            (main-win (vulpea-ui--get-main-window frame))
            (main-buf (when main-win (window-buffer main-win)))
-           (note (vulpea-ui--get-note-from-buffer main-buf))
-           (instance (gethash frame vulpea-ui--sidebar-instances)))
-      (when (and note instance
-                 (vui-instance-buffer instance)
-                 (buffer-live-p (vui-instance-buffer instance)))
-        (with-current-buffer (vui-instance-buffer instance)
-          (setq vulpea-ui--current-note note))
-        (vui-update-props instance (list :note note))))))
+           (note (vulpea-ui--get-note-from-buffer main-buf)))
+      (when note
+        (vulpea-ui-sidebar-refresh)))))
 
 
 ;;; Utility functions
@@ -591,7 +587,9 @@ For use within widget components."
 (defun vulpea-ui-widget-toggle-at-point ()
   "Toggle the widget collapse state at point."
   (interactive)
-  (vulpea-ui-follow-link-at-point))
+  (let ((widget (widget-at (point))))
+    (when widget
+      (widget-apply widget :action))))
 
 
 ;;; Widget wrapper component
@@ -601,17 +599,27 @@ For use within widget components."
 TITLE is the widget title string.
 COUNT is an optional count to display in the header.
 CHILDREN (implicit) is a function returning the widget content."
+  :state ((collapsed vulpea-ui-default-widget-collapsed))
   :render
-  (let ((display-title (if count
-                           (format "%s (%s)" title count)
-                         title)))
-    (vui-collapsible
-      :title display-title
-      :initially-expanded (not vulpea-ui-default-widget-collapsed)
-      :title-face 'vulpea-ui-widget-header-face
-      :indent 2
-      (when children
-        (funcall children)))))
+  (vui-vstack
+   :spacing 0
+   ;; Header
+   (vui-hstack
+    :spacing 1
+    (vui-button (if collapsed "▶" "▼")
+      :on-click (lambda () (vui-set-state :collapsed (not collapsed)))
+      :face 'vulpea-ui-widget-header-face
+      :help-echo nil)
+    (vui-text title :face 'vulpea-ui-widget-header-face)
+    (when count
+      (vui-text (format "(%s)" count) :face 'vulpea-ui-widget-count-face)))
+   ;; Content (when not collapsed)
+   (unless collapsed
+     (when children
+       (vui-vstack
+        :spacing 0
+        :indent 2
+        (funcall children))))))
 
 
 ;;; Shared components
@@ -683,10 +691,7 @@ STRIP-METADATA removes org metadata lines when non-nil."
   :render
   (let ((note (use-vulpea-ui-note)))
     (when note
-      (let* ((note-buf (when (vulpea-note-path note)
-                         (find-buffer-visiting (vulpea-note-path note))))
-             (tick (when note-buf (buffer-modified-tick note-buf)))
-             (stats (vui-use-memo (note tick)
+      (let* ((stats (vui-use-memo (note)
                       (vulpea-ui--compute-stats note)))
              (chars (plist-get stats :chars))
              (words (plist-get stats :words))
@@ -746,11 +751,8 @@ Otherwise reads from disk."
   :render
   (let ((note (use-vulpea-ui-note)))
     (when note
-      (let* ((note-buf (when (vulpea-note-path note)
-                         (find-buffer-visiting (vulpea-note-path note))))
-             (tick (when note-buf (buffer-modified-tick note-buf)))
-             (headings (vui-use-memo (note tick)
-                         (vulpea-ui--parse-headings note))))
+      (let ((headings (vui-use-memo (note)
+                        (vulpea-ui--parse-headings note))))
         (vui-component 'vulpea-ui-widget
           :title "Outline"
           :count (length headings)
@@ -761,7 +763,7 @@ Otherwise reads from disk."
                  (lambda (heading)
                    (vulpea-ui--render-outline-heading heading note))
                  headings)
-              (vui-muted "No headings"))))))))
+              (vui-text "No headings" :face 'shadow))))))))
 
 (defun vulpea-ui--heading-archived-p (hl archive-tag)
   "Return non-nil if HL or any of its ancestors has ARCHIVE-TAG."
@@ -778,13 +780,9 @@ Otherwise reads from disk."
 Returns a list of plists with :title, :level, and :pos."
   (when (and note (vulpea-note-path note))
     (let ((path (vulpea-note-path note))
-          (max-depth vulpea-ui-outline-max-depth)
-          (existing-buf (find-buffer-visiting (vulpea-note-path note))))
+          (max-depth vulpea-ui-outline-max-depth))
       (with-temp-buffer
-        (if existing-buf
-            (insert (with-current-buffer existing-buf
-                      (buffer-substring-no-properties (point-min) (point-max))))
-          (insert-file-contents path))
+        (insert-file-contents path)
         (vulpea-ui--setup-org-mode)
         (let ((headings nil)
               (archive-tag org-archive-tag))
@@ -839,20 +837,19 @@ Groups backlinks by file and shows heading context with optional previews."
                        (vulpea-ui--get-grouped-backlinks note)))
              (groups (plist-get result :groups))
              (filtered-count (plist-get result :filtered-count))
-             (total-count (plist-get result :total-count))
-             (count-display (if (= filtered-count total-count)
-                                filtered-count
-                              (format "%d/%d" filtered-count total-count))))
+             (total-count (plist-get result :total-count)))
         (vui-component 'vulpea-ui-widget
           :title "Backlinks"
-          :count count-display
+          :count (if (= filtered-count total-count)
+                     filtered-count
+                   (format "%d/%d" filtered-count total-count))
           :children
           (lambda ()
             (if groups
                 (vui-vstack
                  :spacing 1
                  (seq-map #'vulpea-ui--render-backlink-group groups))
-              (vui-muted "No backlinks"))))))))
+              (vui-text "No backlinks" :face 'shadow))))))))
 
 (defun vulpea-ui--get-grouped-backlinks (note)
   "Get backlinks to NOTE grouped by file.
@@ -1209,7 +1206,7 @@ This is an internal wrapper around `vulpea-ui-clean-org-markup'."
      ;; File-level note link
      (if file-note
          (vui-component 'vulpea-ui-note-link :note file-note)
-       (vui-muted (file-name-nondirectory path)))
+       (vui-text (file-name-nondirectory path) :face 'shadow))
      ;; Mentions grouped by heading
      (when grouped
        (vui-vstack
@@ -1271,33 +1268,57 @@ Renders the preview as a clickable button to jump to the mention."
   "Render PREVIEW as a clickable button to jump to PATH at POS."
   (let ((type (plist-get preview :type))
         (on-click (lambda () (vulpea-ui--jump-to-file-position path pos))))
-    (let ((indicator (pcase type
-                       ('meta "⊢")
-                       ('header "§")
-                       ('table "▤")
-                       ('list "·")
-                       ('quote ">")
-                       ('code "λ")
-                       ('footnote "†")
-                       (_ nil)))
-          (text (pcase type
-                  ('meta (concat (plist-get preview :key) ": "
-                                 (or (plist-get preview :value) "")))
-                  (_ (or (plist-get preview :text) "")))))
-      (if indicator
-          (vui-hstack
-           :spacing 1
-           (vui-text indicator :face 'vulpea-ui-backlink-context-face)
-           (vui-button text
-             :face 'vulpea-ui-backlink-preview-face
-             :no-decoration t
-             :on-click on-click
-             :help-echo nil))
-        (vui-button text
-          :face 'vulpea-ui-backlink-preview-face
-          :no-decoration t
-          :on-click on-click
-          :help-echo nil)))))
+    (pcase type
+      ('meta
+       (vui-button (concat "⊢ " (plist-get preview :key) ": "
+                           (or (plist-get preview :value) ""))
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil))
+      ('header
+       ;; Header context means the link is IN the heading text - make it clickable
+       (vui-button (concat "§ " (plist-get preview :text))
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil))
+      ('table
+       (vui-button (concat "▤ " (plist-get preview :text))
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil))
+      ('list
+       (vui-button (concat "· " (plist-get preview :text))
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil))
+      ('quote
+       (vui-button (concat "> " (plist-get preview :text))
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil))
+      ('code
+       (vui-button (concat "λ " (plist-get preview :text))
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil))
+      ('footnote
+       (vui-button (concat "† " (plist-get preview :text))
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil))
+      (_
+       (vui-button (or (plist-get preview :text) "")
+         :face 'vulpea-ui-backlink-preview-face
+         :no-decoration t
+         :on-click on-click
+         :help-echo nil)))))
 
 (defun vulpea-ui--jump-to-file-position (path pos)
   "Jump to position POS in file at PATH."
@@ -1338,7 +1359,7 @@ Renders the preview as a clickable button to jump to the mention."
                        (vui-text (format "(%d)" count)
                          :face 'vulpea-ui-widget-count-face))))
                   forward-links))
-              (vui-muted "No links"))))))))
+              (vui-text "No links" :face 'shadow))))))))
 
 (defun vulpea-ui--get-forward-links (note)
   "Get all notes linked from NOTE's file with counts.
@@ -1386,7 +1407,7 @@ Returns a list of plists with :note and :count, sorted by title."
            (seq-map (lambda (widget-sym)
                       (vui-component widget-sym :key widget-sym))
                     widgets)))
-      (vui-muted "No vulpea note selected"))))
+      (vui-text "No vulpea note selected" :face 'shadow))))
 
 (vui-defcomponent vulpea-ui-sidebar-root (note)
   "Root component for the sidebar with NOTE context."
@@ -1404,24 +1425,18 @@ Returns a list of plists with :note and :count, sorted by title."
          (buf-name (vulpea-ui--sidebar-buffer-name frame))
          (buf (get-buffer-create buf-name))
          (sidebar-win (vulpea-ui--get-sidebar-window frame))
-         (original-window (selected-window))
-         (existing-instance (gethash frame vulpea-ui--sidebar-instances)))
+         (original-window (selected-window)))
     ;; Select sidebar window before mount (vui-mount calls switch-to-buffer)
     (when sidebar-win
       (select-window sidebar-win t))
     (with-current-buffer buf
-      (if (and existing-instance
-               (vui-instance-buffer existing-instance)
-               (buffer-live-p (vui-instance-buffer existing-instance)))
-          ;; Reuse existing instance - update props, preserve memos
-          (vui-update-props existing-instance (list :note note))
-        ;; Mount fresh - first render or instance was lost
-        (let ((new-instance
-               (vui-mount
-                (vui-component 'vulpea-ui-sidebar-root :note note)
-                buf-name)))
-          (puthash frame new-instance vulpea-ui--sidebar-instances)))
-      ;; Set current note AFTER render (vui-mount kills local variables)
+      ;; Mount fresh - vui-mount calls kill-all-local-variables
+      (let ((new-instance
+             (vui-mount
+              (vui-component 'vulpea-ui-sidebar-root :note note)
+              buf-name)))
+        (puthash frame new-instance vulpea-ui--sidebar-instances))
+      ;; Set current note AFTER mount (vui-mount kills local variables)
       (setq vulpea-ui--current-note note)
       (goto-char (point-min)))
     ;; Restore original window
@@ -1481,19 +1496,14 @@ Returns a list of plists with :note and :count, sorted by title."
 
 ;;;###autoload
 (defun vulpea-ui-sidebar-refresh ()
-  "Force refresh the sidebar, invalidating all caches."
+  "Force refresh the sidebar content."
   (interactive)
   (let* ((frame (selected-frame))
          (main-win (vulpea-ui--get-main-window frame))
          (main-buf (when main-win (window-buffer main-win)))
-         (note (vulpea-ui--get-note-from-buffer main-buf))
-         (instance (gethash frame vulpea-ui--sidebar-instances)))
-    (when (and note instance
-               (vui-instance-buffer instance)
-               (buffer-live-p (vui-instance-buffer instance)))
-      (with-current-buffer (vui-instance-buffer instance)
-        (setq vulpea-ui--current-note note))
-      (vui-update instance (list :note note)))))
+         (note (vulpea-ui--get-note-from-buffer main-buf)))
+    (setq vulpea-ui--current-note nil)  ; Force update
+    (vulpea-ui--render-sidebar note frame)))
 
 
 ;;; Built-in widget registration
